critic

package
v0.3.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 30, 2025 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Critic

type Critic struct {
	// contains filtered or unexported fields
}

Critic represents the main struct responsible for analyzing code critiques.

func NewCritic

func NewCritic(ai brain.Brain, port int, colorless bool, tools ...tool.Tool) *Critic

NewCritic creates and initializes a new instance of Critic.

func (*Critic) Handler added in v0.2.0

func (c *Critic) Handler(handler protocol.Handler)

Handler sets the message handler for the Critic server.

func (*Critic) ListenAndServe added in v0.2.1

func (c *Critic) ListenAndServe() error

ListenAndServe starts the Critic server and signals readiness via the provided channel.

func (*Critic) Ready added in v0.2.1

func (c *Critic) Ready() <-chan bool

Ready returns a channel that signals when the Critic server is ready to accept requests.

func (*Critic) Review added in v0.2.1

func (c *Critic) Review(job *domain.Job) (*domain.Artifacts, error)

Review sends the provided Java class to the Critic for analysis and returns suggested improvements.

func (*Critic) Shutdown added in v0.2.1

func (c *Critic) Shutdown() error

Shutdown gracefully shuts down the Critic server.

Jump to