fixer

package
v0.3.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 30, 2025 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Fixer

type Fixer struct {
	// contains filtered or unexported fields
}

Fixer is a server that fixes Java code based on suggestions provided.

func NewFixer

func NewFixer(ai brain.Brain, port int, colorless bool) *Fixer

NewFixer creates a new Fixer instance with the provided AI brain and port.

func (*Fixer) Fix added in v0.2.1

func (f *Fixer) Fix(job *domain.Job) (*domain.Artifacts, error)

Fix applies the given suggestions to the provided class and returns the modified class or an error. It communicates with an external fixer service to perform the modifications.

func (*Fixer) Handler added in v0.2.0

func (f *Fixer) Handler(hander protocol.Handler)

Handler sets the handler function for processing requests on the Fixer server.

func (*Fixer) ListenAndServe added in v0.2.1

func (f *Fixer) ListenAndServe() error

ListenAndServe begins the Fixer server and signals readiness through the provided channel.

func (*Fixer) Ready added in v0.2.1

func (f *Fixer) Ready() <-chan bool

Ready returns a channel that signals when the Fixer server is ready to accept requests.

func (*Fixer) Shutdown added in v0.2.1

func (f *Fixer) Shutdown() error

Shutdown gracefully stops the Fixer server.

Jump to